@@ -297,7 +297,6 @@ function setDefaultValuesFromSavedState()
 
 function Main()
 {
-    //alert( document.getElementById('osn_tab').offsetTop);
     //---CROSS
 
     document.getElementById("layer_menu").style.top = -1000 + 'px'; //fast scroll
@@ -400,14 +399,10 @@ function Re_load()
                         x2 = x2_left - sm_s;
                         s_left = 1;
                     }
-                    //alert(key2 + "." + key3);
 
                     var row_offset_top = 0;
-                    //alert('id_tbody_' + key2);
-                    //alert(document.getElementById('id_hide_tbody_' + key2));
                     var tab_hide_button = document.getElementById('id_hide_tbody_' + key2);
 
-                    //alert(tab_hide_button.innerHTML);
                     if (tab_hide_button.innerHTML == 'v') {
                         var fromColumn = document.getElementById(key2 + "." + key3);
                         if (fromColumn) {
@@ -681,6 +676,49 @@ function Save2(callback)
     }
 }
 
+
+function submitSaveDialogAndClose(callback)
+{
+    var $form = $("#save_page");
+    var name = $form.find('input[name="selected_value"]').val().trim();
+    if (name === '') {
+        PMA_ajaxShowMessage(PMA_messages.strEnterValidPageName, false);
+        return;
+    }
+    $('#page_save_dialog').dialog('close');
+
+    if (pmd_tables_enabled) {
+        var $msgbox = PMA_ajaxShowMessage(PMA_messages.strProcessingRequest);
+        PMA_prepareForAjaxRequest($form);
+        $.post($form.attr('action'), $form.serialize() + Get_url_pos(), function (data) {
+            if (data.success === false) {
+                PMA_ajaxShowMessage(data.error, false);
+            } else {
+                PMA_ajaxRemoveMessage($msgbox);
+                MarkSaved();
+                if (data.id) {
+                    selected_page = data.id;
+                }
+                $('#page_name').text(name);
+                if (typeof callback !== 'undefined') {
+                    callback();
+                }
+            }
+        });
+    } else {
+        Save_to_new_page(db, name, Get_url_pos(), function (page) {
+            MarkSaved();
+            if (page.pg_nr) {
+                selected_page = page.pg_nr;
+            }
+            $('#page_name').text(page.page_descr);
+            if (typeof callback !== 'undefined') {
+                callback();
+            }
+        });
+    }
+}
+
 function Save3(callback)
 {
     if (parseInt(selected_page) !== -1) {
@@ -689,44 +727,8 @@ function Save3(callback)
         var button_options = {};
         button_options[PMA_messages.strGo] = function () {
             var $form = $("#save_page");
-            var name = $form.find('input[name="selected_value"]').val().trim();
-            if (name === '') {
-                PMA_ajaxShowMessage(PMA_messages.strEnterValidPageName, false);
-                return;
-            }
-            $(this).dialog('close');
-
-            if (pmd_tables_enabled) {
-                var $msgbox = PMA_ajaxShowMessage(PMA_messages.strProcessingRequest);
-                PMA_prepareForAjaxRequest($form);
-                $.post($form.attr('action'), $form.serialize() + Get_url_pos(), function (data) {
-                    if (data.success === false) {
-                        PMA_ajaxShowMessage(data.error, false);
-                    } else {
-                        PMA_ajaxRemoveMessage($msgbox);
-                        MarkSaved();
-                        if (data.id) {
-                            selected_page = data.id;
-                        }
-                        $('#page_name').text(name);
-                        if (typeof callback !== 'undefined') {
-                            callback();
-                        }
-                    }
-                });
-            } else {
-                Save_to_new_page(db, name, Get_url_pos(), function (page) {
-                    MarkSaved();
-                    if (page.pg_nr) {
-                        selected_page = page.pg_nr;
-                    }
-                    $('#page_name').text(page.page_descr);
-                    if (typeof callback !== 'undefined') {
-                        callback();
-                    }
-                });
-            }
-        };
+            $form.submit();
+        }
         button_options[PMA_messages.strCancel] = function () {
             $(this).dialog('close');
         };
@@ -739,6 +741,10 @@ function Save3(callback)
             .append('<input type="hidden" name="save_page" value="new" />')
             .append('<label for="selected_value">' + PMA_messages.strPageName +
                 '</label>:<input type="text" name="selected_value" />');
+        $form.on('submit', function(e){
+            e.preventDefault();
+            submitSaveDialogAndClose(callback);
+        });
         $('<div id="page_save_dialog"></div>')
             .append($form)
             .dialog({
@@ -1095,7 +1101,7 @@ function Load_page(page) {
 
 function Grid()
 {
-	var value_sent = '';
+    var value_sent = '';
     if (!ON_grid) {
         ON_grid = 1;
         value_sent = 'on';
@@ -1189,18 +1195,12 @@ function Click_field(T, f, PK) // table field
     if (ON_display_field) {
         // if is display field
         if (display_field[T] == f) {
-            //alert(T);
-            //s = '';for(k in display_field)s += k + ' = ' + display_field[k] + ',';alert(s);
             old_class = 'tab_field';
-            //display_field.splice(T, 1);
             delete display_field[T];
-            //s = '';for(k in display_field)s += k + ' = ' + display_field[k] + ', ';alert(s);
-            //n = 0;for(k in display_field)n++;alert(n);
         } else {
             old_class = 'tab_field_3';
             if (display_field[T]) {
                 document.getElementById('id_tr_' + T + '.' + display_field[T]).className = 'tab_field';
-                //display_field.splice(T, 1);
                 delete display_field[T];
             }
             display_field[T] = f;
@@ -1237,8 +1237,7 @@ function New_relation()
             PMA_ajaxShowMessage(data.error, false);
         } else {
             PMA_ajaxRemoveMessage($msgbox);
-            // Load_page(selected_page);
-            $("#designer_tab").click();
+            Load_page(selected_page);
         }
     }); // end $.post()
 }
@@ -1447,7 +1446,6 @@ function Canvas_click(id, event)
     }
     if (selected) {
         // select relations
-        //alert(Key0+' - '+Key1+' - '+Key2+' - '+Key3);
         var left = Glob_X - (document.getElementById('layer_upd_relation').offsetWidth>>1);
         document.getElementById('layer_upd_relation').style.left = left + 'px';
         var top = Glob_Y - document.getElementById('layer_upd_relation').offsetHeight - 10;
@@ -1469,8 +1467,7 @@ function Upd_relation()
             PMA_ajaxShowMessage(data.error, false);
         } else {
             PMA_ajaxRemoveMessage($msgbox);
-            // Load_page(selected_page);
-            $("#designer_tab").click();
+            Load_page(selected_page);
         }
     }); // end $.post()
 }
