@@ -139,7 +139,7 @@ class DbSearch
         ) {
             unset($this->_criteriaColumnName);
         } else {
-            $this->_criteriaColumnName = Util::sqlAddSlashes(
+            $this->_criteriaColumnName = $GLOBALS['dbi']->escapeString(
                 $_REQUEST['criteriaColumnName'], true
             );
         }
@@ -203,9 +203,8 @@ class DbSearch
         // For "as regular expression" (search option 4), LIKE won't be used
         // Usage example: If user is searching for a literal $ in a regexp search,
         // he should enter \$ as the value.
-        $criteriaSearchStringEscaped = Util::sqlAddSlashes(
-            $this->_criteriaSearchString,
-            ($this->_criteriaSearchType == 4 ? false : true)
+        $criteriaSearchStringEscaped = $GLOBALS['dbi']->escapeString(
+            $this->_criteriaSearchString
         );
         // Extract search words or pattern
         $search_words = (($this->_criteriaSearchType > 2)
@@ -335,29 +334,22 @@ class DbSearch
         $html_output .= '</td>';
         // Displays browse/delete link if result count > 0
         if ($res_cnt > 0) {
-            $this_url_params['sql_query'] = $newsearchsqls['select_columns'];
+            $this_url_params['db'] = htmlspecialchars($GLOBALS['db']);
+            $this_url_params['table'] = htmlspecialchars($each_table);
             $browse_result_path = 'sql.php' . PMA_URL_getCommon($this_url_params);
-            $html_output .= '<td><a name="browse_search" class="ajax" href="'
-                . $browse_result_path . '" onclick="loadResult(\''
-                . $browse_result_path . '\',\''
-                . PMA_escapeJsString(htmlspecialchars($each_table)) . '\',\''
-                . PMA_URL_getCommon(
-                    array(
-                        'db' => $GLOBALS['db'], 'table' => $each_table
-                    )
-                ) . '\''
-                . ');return false;" >'
+            $html_output .= '<td><a name="browse_search" '
+                . ' class="ajax browse_results" href="'
+                . $browse_result_path . '" '
+                . 'data-browse-sql="'
+                . htmlspecialchars($newsearchsqls['select_columns']). '" '
+                . 'data-table-name="' . htmlspecialchars($each_table) . '" >'
                 . __('Browse') . '</a></td>';
-            $this_url_params['sql_query'] = $newsearchsqls['delete'];
-            $delete_result_path = 'sql.php' . PMA_URL_getCommon($this_url_params);
-            $html_output .= '<td><a name="delete_search" class="ajax" href="'
-                . $delete_result_path . '" onclick="deleteResult(\''
-                . $delete_result_path . '\' , \''
-                . PMA_escapeJsString(sprintf(
-                    __('Delete the matches for the %s table?'),
-                    htmlspecialchars($each_table)
-                ))
-                . '\');return false;">'
+
+            $delete_result_path = $browse_result_path;
+            $html_output .= '<td><a name="delete_search" class="ajax delete_results"'
+                . ' href="' . $delete_result_path . '"'
+                . ' data-delete-sql="' . htmlspecialchars($newsearchsqls['delete']) . '"'
+                . ' data-table-name="' . htmlspecialchars($each_table) . '" >'
                 . __('Delete') . '</a></td>';
         } else {
             $html_output .= '<td>&nbsp;</td>'
