@@ -123,8 +123,8 @@ class Tracker
         }
 
         $sql_query = " SELECT tracking_active FROM " . self::_getTrackingTable() .
-        " WHERE db_name = '" . Util::sqlAddSlashes($dbname) . "' " .
-        " AND table_name = '" . Util::sqlAddSlashes($tablename) . "' " .
+        " WHERE db_name = '" . $GLOBALS['dbi']->escapeString($dbname) . "' " .
+        " AND table_name = '" . $GLOBALS['dbi']->escapeString($tablename) . "' " .
         " ORDER BY version DESC";
 
         $row = $GLOBALS['dbi']->fetchArray(PMA_queryAsControlUser($sql_query));
@@ -144,8 +144,9 @@ class Tracker
     static public function getLogComment()
     {
         $date = date('Y-m-d H:i:s');
+        $user = preg_replace('/\s+/', ' ', $GLOBALS['cfg']['Server']['user']);
 
-        return "# log " . $date . " " . $GLOBALS['cfg']['Server']['user'] . "\n";
+        return "# log " . $date . " " . $user . "\n";
     }
 
     /**
@@ -242,15 +243,15 @@ class Tracker
         "tracking " .
         ") " .
         "values (
-        '" . Util::sqlAddSlashes($dbname) . "',
-        '" . Util::sqlAddSlashes($tablename) . "',
-        '" . Util::sqlAddSlashes($version) . "',
-        '" . Util::sqlAddSlashes($date) . "',
-        '" . Util::sqlAddSlashes($date) . "',
-        '" . Util::sqlAddSlashes($snapshot) . "',
-        '" . Util::sqlAddSlashes($create_sql) . "',
-        '" . Util::sqlAddSlashes("\n") . "',
-        '" . Util::sqlAddSlashes($tracking_set)
+        '" . $GLOBALS['dbi']->escapeString($dbname) . "',
+        '" . $GLOBALS['dbi']->escapeString($tablename) . "',
+        '" . $GLOBALS['dbi']->escapeString($version) . "',
+        '" . $GLOBALS['dbi']->escapeString($date) . "',
+        '" . $GLOBALS['dbi']->escapeString($date) . "',
+        '" . $GLOBALS['dbi']->escapeString($snapshot) . "',
+        '" . $GLOBALS['dbi']->escapeString($create_sql) . "',
+        '" . $GLOBALS['dbi']->escapeString("\n") . "',
+        '" . $GLOBALS['dbi']->escapeString($tracking_set)
         . "' )";
 
         $result = PMA_queryAsControlUser($sql_query);
@@ -280,12 +281,12 @@ class Tracker
         $sql_query = "/*NOTRACK*/\n"
             . "DELETE FROM " . self::_getTrackingTable()
             . " WHERE `db_name` = '"
-            . Util::sqlAddSlashes($dbname) . "'"
+            . $GLOBALS['dbi']->escapeString($dbname) . "'"
             . " AND `table_name` = '"
-            . Util::sqlAddSlashes($tablename) . "'";
+            . $GLOBALS['dbi']->escapeString($tablename) . "'";
         if ($version) {
             $sql_query .= " AND `version` = '"
-                . Util::sqlAddSlashes($version) . "'";
+                . $GLOBALS['dbi']->escapeString($version) . "'";
         }
         $result = PMA_queryAsControlUser($sql_query);
 
@@ -338,15 +339,15 @@ class Tracker
         "tracking " .
         ") " .
         "values (
-        '" . Util::sqlAddSlashes($dbname) . "',
-        '" . Util::sqlAddSlashes('') . "',
-        '" . Util::sqlAddSlashes($version) . "',
-        '" . Util::sqlAddSlashes($date) . "',
-        '" . Util::sqlAddSlashes($date) . "',
-        '" . Util::sqlAddSlashes('') . "',
-        '" . Util::sqlAddSlashes($create_sql) . "',
-        '" . Util::sqlAddSlashes("\n") . "',
-        '" . Util::sqlAddSlashes($tracking_set)
+        '" . $GLOBALS['dbi']->escapeString($dbname) . "',
+        '" . $GLOBALS['dbi']->escapeString('') . "',
+        '" . $GLOBALS['dbi']->escapeString($version) . "',
+        '" . $GLOBALS['dbi']->escapeString($date) . "',
+        '" . $GLOBALS['dbi']->escapeString($date) . "',
+        '" . $GLOBALS['dbi']->escapeString('') . "',
+        '" . $GLOBALS['dbi']->escapeString($create_sql) . "',
+        '" . $GLOBALS['dbi']->escapeString("\n") . "',
+        '" . $GLOBALS['dbi']->escapeString($tracking_set)
         . "' )";
 
         $result = PMA_queryAsControlUser($sql_query);
@@ -374,9 +375,9 @@ class Tracker
 
         $sql_query = " UPDATE " . self::_getTrackingTable() .
         " SET `tracking_active` = '" . $new_state . "' " .
-        " WHERE `db_name` = '" . Util::sqlAddSlashes($dbname) . "' " .
-        " AND `table_name` = '" . Util::sqlAddSlashes($tablename) . "' " .
-        " AND `version` = '" . Util::sqlAddSlashes($version) . "' ";
+        " WHERE `db_name` = '" . $GLOBALS['dbi']->escapeString($dbname) . "' " .
+        " AND `table_name` = '" . $GLOBALS['dbi']->escapeString($tablename) . "' " .
+        " AND `version` = '" . $GLOBALS['dbi']->escapeString($version) . "' ";
 
         $result = PMA_queryAsControlUser($sql_query);
 
@@ -412,7 +413,7 @@ class Tracker
         if (is_array($new_data)) {
             foreach ($new_data as $data) {
                 $new_data_processed .= '# log ' . $date . ' ' . $data['username']
-                    . Util::sqlAddSlashes($data['statement']) . "\n";
+                    . $GLOBALS['dbi']->escapeString($data['statement']) . "\n";
             }
         } else {
             $new_data_processed = $new_data;
@@ -420,9 +421,9 @@ class Tracker
 
         $sql_query = " UPDATE " . self::_getTrackingTable() .
         " SET `" . $save_to . "` = '" . $new_data_processed . "' " .
-        " WHERE `db_name` = '" . Util::sqlAddSlashes($dbname) . "' " .
-        " AND `table_name` = '" . Util::sqlAddSlashes($tablename) . "' " .
-        " AND `version` = '" . Util::sqlAddSlashes($version) . "' ";
+        " WHERE `db_name` = '" . $GLOBALS['dbi']->escapeString($dbname) . "' " .
+        " AND `table_name` = '" . $GLOBALS['dbi']->escapeString($tablename) . "' " .
+        " AND `version` = '" . $GLOBALS['dbi']->escapeString($version) . "' ";
 
         $result = PMA_queryAsControlUser($sql_query);
 
@@ -478,8 +479,8 @@ class Tracker
     static public function getVersion($dbname, $tablename, $statement = null)
     {
         $sql_query = " SELECT MAX(version) FROM " . self::_getTrackingTable() .
-        " WHERE `db_name` = '" . Util::sqlAddSlashes($dbname) . "' " .
-        " AND `table_name` = '" . Util::sqlAddSlashes($tablename) . "' ";
+        " WHERE `db_name` = '" . $GLOBALS['dbi']->escapeString($dbname) . "' " .
+        " AND `table_name` = '" . $GLOBALS['dbi']->escapeString($tablename) . "' ";
 
         if ($statement != "") {
             $sql_query .= " AND FIND_IN_SET('"
@@ -507,12 +508,12 @@ class Tracker
     static public function getTrackedData($dbname, $tablename, $version)
     {
         $sql_query = " SELECT * FROM " . self::_getTrackingTable() .
-            " WHERE `db_name` = '" . Util::sqlAddSlashes($dbname) . "' ";
+            " WHERE `db_name` = '" . $GLOBALS['dbi']->escapeString($dbname) . "' ";
         if (! empty($tablename)) {
             $sql_query .= " AND `table_name` = '"
-                . Util::sqlAddSlashes($tablename) . "' ";
+                . $GLOBALS['dbi']->escapeString($tablename) . "' ";
         }
-        $sql_query .= " AND `version` = '" . Util::sqlAddSlashes($version)
+        $sql_query .= " AND `version` = '" . $GLOBALS['dbi']->escapeString($version)
             . "' " . " ORDER BY `version` DESC LIMIT 1";
 
         $mixed = $GLOBALS['dbi']->fetchAssoc(PMA_queryAsControlUser($sql_query));
@@ -916,14 +917,14 @@ class Tracker
                     . " UPDATE " . self::_getTrackingTable()
                     . " SET " . Util::backquote($save_to)
                     . " = CONCAT( " . Util::backquote($save_to) . ",'\n"
-                    . Util::sqlAddSlashes($query) . "') ,"
+                    . $GLOBALS['dbi']->escapeString($query) . "') ,"
                     . " `date_updated` = '" . $date . "' ";
 
                 // If table was renamed we have to change
                 // the tablename attribute in pma_tracking too
                 if ($result['identifier'] == 'RENAME TABLE') {
                     $sql_query .= ', `table_name` = \''
-                        . Util::sqlAddSlashes($result['tablename_after_rename'])
+                        . $GLOBALS['dbi']->escapeString($result['tablename_after_rename'])
                         . '\' ';
                 }
 
@@ -934,10 +935,10 @@ class Tracker
                 // we want to track
                 $sql_query .=
                 " WHERE FIND_IN_SET('" . $result['identifier'] . "',tracking) > 0" .
-                " AND `db_name` = '" . Util::sqlAddSlashes($dbname) . "' " .
+                " AND `db_name` = '" . $GLOBALS['dbi']->escapeString($dbname) . "' " .
                 " AND `table_name` = '"
-                . Util::sqlAddSlashes($result['tablename']) . "' " .
-                " AND `version` = '" . Util::sqlAddSlashes($version) . "' ";
+                . $GLOBALS['dbi']->escapeString($result['tablename']) . "' " .
+                " AND `version` = '" . $GLOBALS['dbi']->escapeString($version) . "' ";
 
                 PMA_queryAsControlUser($sql_query);
             }
