@@ -35,7 +35,7 @@ if (! defined('MYSQLI_BINARY_FLAG')) {
 }
 
 /**
- * @see http://bugs.php.net/36007
+ * @see https://bugs.php.net/36007
  */
 if (! defined('MYSQLI_TYPE_NEWDECIMAL')) {
     define('MYSQLI_TYPE_NEWDECIMAL', 246);
@@ -64,7 +64,6 @@ class DBIMysqli implements DBIExtension
      * @param string $host          mysql hostname
      * @param string $user          mysql user name
      * @param string $password      mysql user password
-     * @param string $dbname        database name
      * @param int    $server_port   server port
      * @param string $server_socket server socket
      * @param int    $client_flags  client flags of connection
@@ -73,7 +72,7 @@ class DBIMysqli implements DBIExtension
      * @return bool
      */
     private function _realConnect(
-        $link, $host, $user, $password, $dbname, $server_port,
+        $link, $host, $user, $password, $server_port,
         $server_socket, $client_flags = null, $persistent = false
     ) {
         global $cfg;
@@ -89,7 +88,7 @@ class DBIMysqli implements DBIExtension
                 $host,
                 $user,
                 $password,
-                $dbname,
+                '',
                 $server_port,
                 $server_socket
             );
@@ -99,7 +98,7 @@ class DBIMysqli implements DBIExtension
                 $host,
                 $user,
                 $password,
-                $dbname,
+                '',
                 $server_port,
                 $server_socket,
                 $client_flags
@@ -126,9 +125,6 @@ class DBIMysqli implements DBIExtension
         global $cfg;
 
         $server_port = $GLOBALS['dbi']->getServerPort($server);
-        if ($server_port === null) {
-            $server_port = 0;
-        }
         $server_socket = $GLOBALS['dbi']->getServerSocket($server);
 
         if ($server) {
@@ -141,7 +137,11 @@ class DBIMysqli implements DBIExtension
 
         $link = mysqli_init();
 
-        mysqli_options($link, MYSQLI_OPT_LOCAL_INFILE, true);
+        if (defined('PMA_ENABLE_LDI')) {
+            mysqli_options($link, MYSQLI_OPT_LOCAL_INFILE, true);
+        } else {
+            mysqli_options($link, MYSQLI_OPT_LOCAL_INFILE, false);
+        }
 
         $client_flags = 0;
 
@@ -152,14 +152,17 @@ class DBIMysqli implements DBIExtension
 
         /* Optionally enable SSL */
         if ($cfg['Server']['ssl']) {
-            mysqli_ssl_set(
-                $link,
-                $cfg['Server']['ssl_key'],
-                $cfg['Server']['ssl_cert'],
-                $cfg['Server']['ssl_ca'],
-                $cfg['Server']['ssl_ca_path'],
-                $cfg['Server']['ssl_ciphers']
-            );
+            $client_flags |= MYSQLI_CLIENT_SSL;
+            if (!empty($cfg['Server']['ssl_key'])) {
+                mysqli_ssl_set(
+                    $link,
+                    $cfg['Server']['ssl_key'],
+                    $cfg['Server']['ssl_cert'],
+                    $cfg['Server']['ssl_ca'],
+                    $cfg['Server']['ssl_ca_path'],
+                    $cfg['Server']['ssl_ciphers']
+                );
+            }
             /*
              * disables SSL certificate validation on mysqlnd for MySQL 5.6 or later
              * @link https://bugs.php.net/bug.php?id=68344
@@ -181,7 +184,6 @@ class DBIMysqli implements DBIExtension
                 $cfg['Server']['host'],
                 $user,
                 $password,
-                false,
                 $server_port,
                 $server_socket,
                 $client_flags
@@ -197,7 +199,6 @@ class DBIMysqli implements DBIExtension
                     $cfg['Server']['host'],
                     $user,
                     '',
-                    false,
                     $server_port,
                     $server_socket,
                     $client_flags
@@ -209,13 +210,12 @@ class DBIMysqli implements DBIExtension
                 $server['host'],
                 $user,
                 $password,
-                false,
                 $server_port,
                 $server_socket
             );
         }
 
-        if ($return_value === false) {
+        if ($return_value === false || is_null($return_value)) {
             return false;
         }
 
@@ -615,4 +615,17 @@ class DBIMysqli implements DBIExtension
         }
         return implode(' ', $flags);
     }
+
+    /**
+     * returns properly escaped string for use in MySQL queries
+     *
+     * @param mixed  $link database link
+     * @param string $str  string to be escaped
+     *
+     * @return string a MySQL escaped string
+     */
+    public function escapeString($link, $str)
+    {
+        return mysqli_real_escape_string($link, $str);
+    }
 }
