@@ -37,11 +37,11 @@ $GLOBALS['is_grantuser'] = $GLOBALS['dbi']->isUserType('grant');
 $GLOBALS['is_createuser'] = $GLOBALS['dbi']->isUserType('create');
 
 // now, select the mysql db
-if ($GLOBALS['is_superuser'] && ! PMA_DRIZZLE) {
+if ($GLOBALS['is_superuser']) {
     $GLOBALS['dbi']->selectDb('mysql', $GLOBALS['userlink']);
 }
 
-PMA_Util::checkParameters(
+PMA\libraries\Util::checkParameters(
     array('is_superuser', 'url_query'), false
 );
 
