@@ -19,8 +19,7 @@ use SqlParser\TokensList;
  * @category   Keywords
  * @package    SqlParser
  * @subpackage Components
- * @author     Dan Ungureanu <udan1107@gmail.com>
- * @license    http://opensource.org/licenses/GPL-2.0 GNU Public License
+ * @license    https://www.gnu.org/licenses/gpl-2.0.txt GPL-2.0+
  */
 class Condition extends Component
 {
@@ -38,6 +37,7 @@ class Condition extends Component
      * @var array
      */
     public static $ALLOWED_KEYWORDS = array(
+        'ALL'                           => 1,
         'AND'                           => 1,
         'BETWEEN'                       => 1,
         'EXISTS'                        => 1,
@@ -52,6 +52,8 @@ class Condition extends Component
         'NOT'                           => 1,
         'NULL'                          => 1,
         'OR'                            => 1,
+        'REGEXP'                        => 1,
+        'RLIKE'                         => 1,
         'XOR'                           => 1,
     );
 
@@ -182,6 +184,9 @@ class Condition extends Component
                 if ($token->value === '(') {
                     ++$brackets;
                 } elseif ($token->value === ')') {
+                    if ($brackets == 0) {
+                        break;
+                    }
                     --$brackets;
                 }
             }
