@@ -19,8 +19,7 @@ use SqlParser\TokensList;
  * @category   Keywords
  * @package    SqlParser
  * @subpackage Components
- * @author     Dan Ungureanu <udan1107@gmail.com>
- * @license    http://opensource.org/licenses/GPL-2.0 GNU Public License
+ * @license    https://www.gnu.org/licenses/gpl-2.0.txt GPL-2.0+
  */
 class JoinKeyword extends Component
 {
@@ -31,6 +30,7 @@ class JoinKeyword extends Component
      * @var array
      */
     public static $JOINS = array(
+        'CROSS JOIN'                    => 'CROSS',
         'FULL JOIN'                     => 'FULL',
         'FULL OUTER JOIN'               => 'FULL',
         'INNER JOIN'                    => 'INNER',
@@ -39,6 +39,12 @@ class JoinKeyword extends Component
         'LEFT OUTER JOIN'               => 'LEFT',
         'RIGHT JOIN'                    => 'RIGHT',
         'RIGHT OUTER JOIN'              => 'RIGHT',
+        'NATURAL JOIN'                  => 'NATURAL',
+        'NATURAL LEFT JOIN'             => 'NATURAL LEFT',
+        'NATURAL LEFT JOIN'             => 'NATURAL LEFT',
+        'NATURAL RIGHT JOIN'            => 'NATURAL RIGHT',
+        'NATURAL LEFT OUTER JOIN'       => 'NATURAL LEFT OUTER',
+        'NATURAL RIGHT OUTER JOIN'      => 'NATURAL RIGHT OUTER',
         'STRAIGHT_JOIN'                 => 'STRAIGHT',
     );
 
@@ -147,6 +153,18 @@ class JoinKeyword extends Component
                         $state = 3;
                     } elseif ($token->value === 'USING') {
                         $state = 4;
+                    } else {
+                        if (($token->type === Token::TYPE_KEYWORD)
+                            && (!empty(static::$JOINS[$token->value]))
+                        ) {
+                            $ret[] = $expr;
+                            $expr = new JoinKeyword();
+                            $expr->type = static::$JOINS[$token->value];
+                            $state = 1;
+                        } else {
+                            /* Next clause is starting */
+                            break;
+                        }
                     }
                 }
             } elseif ($state === 3) {
@@ -183,8 +201,9 @@ class JoinKeyword extends Component
         foreach ($component as $c) {
             $ret[] = array_search($c->type, static::$JOINS) . ' ' . $c->expr
                 . (!empty($c->on)
-                    ? ' ON ' . Condition::build($c->on)
-                    : ' USING ' . ArrayObj::build($c->using));
+                    ? ' ON ' . Condition::build($c->on) : '')
+                . (!empty($c->using)
+                    ? ' USING ' . ArrayObj::build($c->using) : '');
         }
         return implode(' ', $ret);
     }
