@@ -17,8 +17,7 @@ use SqlParser\Statements\SelectStatement;
  * @category   Keywords
  * @package    SqlParser
  * @subpackage Components
- * @author     Dan Ungureanu <udan1107@gmail.com>
- * @license    http://opensource.org/licenses/GPL-2.0 GNU Public License
+ * @license    https://www.gnu.org/licenses/gpl-2.0.txt GPL-2.0+
  */
 class UnionKeyword extends Component
 {
@@ -31,6 +30,10 @@ class UnionKeyword extends Component
      */
     public static function build($component, array $options = array())
     {
-        return implode(' UNION ', $component);
+        $tmp = array();
+        foreach ($component as $component) {
+            $tmp[] = $component[0] . ' ' . $component[1];
+        }
+        return implode(' ', $tmp);
     }
 }
