@@ -7,14 +7,18 @@
  *
  * @package PhpMyAdmin
  */
+use PMA\libraries\config\PageSettings;
+use PMA\libraries\Response;
+use PMA\libraries\Util;
 
 /**
  * Gets the variables sent or posted to this script and displays the header
  */
 require_once 'libraries/common.inc.php';
-require_once 'libraries/config/page_settings.class.php';
+require_once 'libraries/config/user_preferences.forms.php';
+require_once 'libraries/config/page_settings.forms.php';
 
-PMA_PageSettings::showGroup('Edit');
+PageSettings::showGroup('Edit');
 
 /**
  * Ensures db and table are valid, else moves to the "parent" script
@@ -50,7 +54,7 @@ require_once 'libraries/file_listing.lib.php';
  * (at this point, $GLOBALS['goto'] will be set but could be empty)
  */
 if (empty($GLOBALS['goto'])) {
-    if (/*overload*/mb_strlen($table)) {
+    if (mb_strlen($table)) {
         // avoid a problem (see bug #2202709)
         $GLOBALS['goto'] = 'tbl_sql.php';
     } else {
@@ -72,10 +76,9 @@ $comments_map = PMA_getCommentsMap($db, $table);
 /**
  * Load JavaScript files
  */
-$response = PMA_Response::getInstance();
+$response = Response::getInstance();
 $header   = $response->getHeader();
 $scripts  = $header->getScripts();
-$scripts->addFile('functions.js');
 $scripts->addFile('sql.js');
 $scripts->addFile('tbl_change.js');
 $scripts->addFile('big_ints.js');
@@ -90,7 +93,7 @@ $scripts->addFile('gis_data_editor.js');
  * $disp_message come from tbl_replace.php
  */
 if (! empty($disp_message)) {
-    $response->addHTML(PMA_Util::getMessage($disp_message, null));
+    $response->addHTML(Util::getMessage($disp_message, null));
 }
 
 $table_columns = PMA_getTableColumns($db, $table);
@@ -152,7 +155,7 @@ $html_output .= PMA_getHtmlForInsertEditFormHeader($has_blob_field, $is_upload);
 
 $html_output .= PMA_URL_getHiddenInputs($_form_params);
 
-$titles['Browse'] = PMA_Util::getIcon('b_browse.png', __('Browse foreign values'));
+$titles['Browse'] = Util::getIcon('b_browse.png', __('Browse foreign values'));
 
 // user can toggle the display of Function column and column types
 // (currently does not work for multi-edits)
@@ -214,7 +217,7 @@ $html_output .= PMA_getActionsPanel(
 
 if ($biggest_max_file_size > 0) {
     $html_output .= '        '
-        . PMA_Util::generateHiddenMaxFileSize(
+        . Util::generateHiddenMaxFileSize(
             $biggest_max_file_size
         ) . "\n";
 }
